<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Syntax: %t - song title,
%a - album, %r - artist, %f - file name,
%l - song length (MM:SS), %c - current song position (MM:SS),
%p - percents of played song, %n - player name, %v - player version
</source>
        <translation>Sözdizimi: %t - şarkı başlığı,
%a - albüm, %r - sanatçı, %f - dosya adı,
%l - şarkı uzunluğu (MM:SS), %c - şimdiki şarkının konumu (MM:SS),
%p - çalan şarkının yüzdesi, %n - oynatıcı adı, %v - oynatıcı versiyon
</translation>
    </message>
    <message>
        <source>Pseudo-OSD for MediaPlayer</source>
        <translation>Pseudo-OSD için MediaPlayer</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <source>MediaPlayer statuses in description</source>
        <translation>Medya Oynatıcı durumlardaki tanımı</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Değiştir</translation>
    </message>
    <message>
        <source>MediaPlayer description format</source>
        <translation>Medya Oynatıcı tanım formatı</translation>
    </message>
    <message>
        <source>Here specify format which will replace &apos;#{player}&apos; tag when you will use it in description while setting status.</source>
        <translation>Durum ayarlanırken açıklama olarak kullanılacak &apos;#{player}&apos; etiketini buradaki formatla değiştir.</translation>
    </message>
    <message>
        <source>Signatures to cut</source>
        <translation>İmzaları kes</translation>
    </message>
    <message>
        <source>Crap to cut</source>
        <translation>Gereksizleri kes</translation>
    </message>
    <message>
        <source>Enable pseudo-OSD</source>
        <translation>pseudo-OSD açık</translation>
    </message>
    <message>
        <source>Enables pseudo-OSD done by Kadu hints. Shows currently played title in hint.</source>
        <translation>Kadu ipucu olarak pseudo-OSD izin ver. Şuan oynatılanın başlığını ipucu olarak göster.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer keyboard shortcuts in chat window</source>
        <translation>Konuşma penceresinde Medya Oynatıcı klavye kısayol tuşları açık</translation>
    </message>
    <message>
        <source>Put statuses switch to dock menu</source>
        <translation>Dock menü üzerinden durumları değiştirmeyi koyun</translation>
    </message>
    <message>
        <source>Enable this to put MediaPlayer statuses switch into docked icon menu.</source>
        <translation>Medya Oynatıcı durumlarını değiştirmek için dock simge menüsüne koyun</translation>
    </message>
    <message>
        <source>Signature Cutting</source>
        <translation>İmza Kesiliyor</translation>
    </message>
    <message>
        <source>Other Settings</source>
        <translation>Diğer Ayarlar</translation>
    </message>
    <message>
        <source>With this option enabled you'll be able to control
your MediaPlayer in chat window by keyboard shortcuts:
Win+ Enter/Backspace/Left/Right/Up/Down.</source>
        <translation>Bu seçeneği aktif ettiğinizde konuşma penceresinde Medya 
Oynatıcınızı klavye kısayol tuşlarıyla kontrol edebilceksiniz:
Win+ Enter/Backspace/Left/Right/Up/Down.</translation>
    </message>
    <message>
        <source>Add in the Front</source>
        <translation>Önüne Ekle</translation>
    </message>
    <message>
        <source>Add at the Back</source>
        <translation>Arkasına Ekle</translation>
    </message>
    <message>
        <source>Replace &apos;#{player}&apos; Tag</source>
        <translation>&apos;#{player}&apos; Etiketini Değiştir</translation>
    </message>
    <message>
        <source>Extras</source>
        <translation>Ekstralar</translation>
    </message>
    <message>
        <source>Media Player</source>
        <translation>Medya Oynatıcı</translation>
    </message>
    <message>
        <source>MediaPlayer message format in chat window</source>
        <translation>Konuşma penceresinde Medya Oynatıcı mesaj formatı</translation>
    </message>
    <message>
        <source>Enable signature cutting</source>
        <translation>İmza kesimini etkinleştir</translation>
    </message>
    <message>
        <source>Enable removing non-essential stuff from audio file titles</source>
        <translation>Ses dosya başlıklarının gerekli olmayan kısımlarını kaldır</translation>
    </message>
</context>
<context>
    <name>MediaPlayer</name>
    <message>
        <source>Put formated string</source>
        <translation>Formatlı dize koyun</translation>
    </message>
    <message>
        <source>Put song title</source>
        <translation>Şarkı başlığını koy</translation>
    </message>
    <message>
        <source>Put song file name</source>
        <translation>Şarkı dosyası adını koy</translation>
    </message>
    <message>
        <source>Send all playlist titles</source>
        <translation>Bütün çalma listesi başlıklarını gönder</translation>
    </message>
    <message>
        <source>Send all playlist files</source>
        <translation>Bütün çalma listesi dosyalarını gönder</translation>
    </message>
    <message>
        <source>Enable MediaPlayer statuses</source>
        <translation>Medya Oynatıcı durumları açık</translation>
    </message>
    <message>
        <source>MediaPlayer</source>
        <translation>Medya Oynatıcı</translation>
    </message>
    <message>
        <source>%1 isn&apos;t running!</source>
        <translation>%1 çalışmıyor!</translation>
    </message>
    <message>
        <source>You&apos;re trying to send %1 entries of %2 playlist.&lt;br&gt;It will be split and sent in few messages&lt;br&gt;Are you sure to do that?</source>
        <translation>%2 çalma listesinin %1 girdilerini göndermeye çalışıyorsunuz.&lt;br&gt;Bunlar ayırılacak ve bir kaç mesaj halinde gönderilecek&lt;br&gt;Bunu yapmak istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <source>Playback stopped.</source>
        <translation>Playback durduruldu.</translation>
    </message>
    <message>
        <source>Player turned off.</source>
        <translation>Oynatıcı kapandı.</translation>
    </message>
    <message>
        <source>Enable MediaPlayer Statuses</source>
        <translation>Medya Oynatıcı Durumları Açık</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Yürüt</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Durdur</translation>
    </message>
    <message>
        <source>Previous Track</source>
        <translation>Önceki Parça</translation>
    </message>
    <message>
        <source>Next Track</source>
        <translation>Sonraki Parça</translation>
    </message>
    <message>
        <source>Volume Up</source>
        <translation>Sesi Yükselt</translation>
    </message>
    <message>
        <source>Volume Down</source>
        <translation>Sesi Alçalt</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>More than 1/10 of titles you&apos;re trying to send are empty.&lt;br&gt;Perhaps %1 hasn&apos;t read all titles yet, give its some more time.&lt;br&gt;Do you want to send playlist anyway?</source>
        <translation>1/10 dan fazla boş başlık göndermeye çalışıyorsunuz.&lt;br&gt; Muhtemelen %1 bütün başlıkları henüz okuyamayacak, biraz daha fazla zaman verin.&lt;br&gt;Yinede çalma listesini göndermek istediğinizden emin  misiniz?</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Duraklat</translation>
    </message>
    <message>
        <source>Player isn&apos;t running!</source>
        <translation>Oynatıcı çalışmıyor!</translation>
    </message>
    <message>
        <source>Send anyway</source>
        <translation>Yinede gönder</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Gönder</translation>
    </message>
</context>
</TS>